Repository Information — PyMedPhys

Toggle navigation sidebar
Toggle in-page Table of Contents

# Repository Information

- Repository File Structure
- Documentation Guide
  - Documentation structure and philosophy
  - Building the documentation on your workstation
  - Docstring extraction
- pymedphys Release Procedure
  - Determine next release version
  - Create a branch to prepare the release
  - Update version in pyproject.toml
  - Update CHANGELOG
  - Create release pull request
  - Publish Release